import { act, render } from "@testing-library/react";
import React from "react";
import { beforeEach, describe, expect, test, vi } from "vitest";
import { AuthIFrame } from "..";
import { config } from "../../config";

describe("AuthIFrame", () => {
  let mockLocalStorage;

  beforeEach(() => {
    mockLocalStorage = {
      getItem: vi.fn(),
      setItem: vi.fn(),
    };
    Object.defineProperty(window, "localStorage", { value: mockLocalStorage });
  });

  test("should set isAuthenticated to true when message received", async () => {
    const onChange = vi.fn();

    render(<AuthIFrame onChange={onChange} />);

    expect(onChange).toHaveBeenCalledWith({ isAuthenticated: false });

    const mockEvent = new MessageEvent("message", {
      data: "token",
      origin: config.baseUrl,
    });

    await act(() => window.dispatchEvent(mockEvent));
    expect(onChange).toHaveBeenCalledWith({ isAuthenticated: true });
    expect(window.localStorage.setItem).toHaveBeenCalledWith(
      config.localstorageKeys.token,
      "token"
    );
  });
});
